OC.L10N.register(
    "groupfolders",
    {
    "You cannot remove your own read permission." : "Et voi poistaa omaa lukuoikeuttasi.",
    "Team folders" : "Tiimikansiot",
    "Team Folders" : "Tiimikansiot",
    "Denied (Inherited permission)" : "Estetty (peritty oikeus)",
    "Allowed (Inherited permission)" : "Sallittu (peritty oikeus)",
    "Denied" : "Estetty",
    "Allowed" : "Sallittu",
    "Access denied" : "Pääsy estetty",
    "Access allowed" : "Pääsy sallittu",
    "Inherit permission" : "Peru oikeudet",
    "Deny" : "Kiellä",
    "Allow" : "Salli",
    "Group" : "Ryhmä",
    "Team" : "Tiimi",
    "Advanced permissions for Team folder" : "Tiimikansion edistyneet oikeudet",
    "Team folder" : "Tiimikansio",
    "Read" : "Lue",
    "Write" : "Kirjoita",
    "Create" : "Luo",
    "Delete" : "Poista",
    "Share" : "Jako",
    "You" : "Sinä",
    "Remove access rule" : "Poista käyttösääntö",
    "Add new rule" : "Lisää uusi sääntö",
    "Select a user or group" : "Valitse käyttäjä tai ryhmä",
    "Open Team folder" : "Avaa tiimikansio",
    "Permission denied. User does not have sufficient permissions." : "Pääsy estetty. Käyttäjällä ei ole riittävästi oikeuksia.",
    "Unexpected status from server" : "Odottamaton tila palvelimelta",
    "List of Team folders." : "Lista tiimikansioista.",
    "No Team folders yet" : "Ei tiimikansioita vielä",
    "Team folders will show up here" : "Tiimikansiot näkyvät täällä",
    "Add group" : "Lisää ryhmä",
    "Default" : "Oletus",
    "Unlimited" : "Rajoittamaton",
    "Are you sure you want to delete \"{folderName}\" and all files inside? This operation cannot be undone" : "Haluatko varmasti poistaa kansion \"{folderName}\" ja kaikki sen sisällä olevat tiedostot? Tätä toimintoa ei voi perua",
    "Delete \"{folderName}\"?" : "Poistetaanko \"{folderName}\"?",
    "Group or team" : "Ryhmä tai tiimi",
    "Folder name" : "Kansion nimi",
    "Quota" : "Kiintiö",
    "Advanced Permissions" : "Edistyneet oikeudet",
    "Pagination of team folders" : "Tiimikansioiden sivutus",
    "Previous" : "Edellinen",
    "Next" : "Seuraava",
    "User" : "Käyttäjä",
    "Unknown" : "Tuntematon",
    "None" : "Ei mitään",
    "No other groups or teams available" : "Muita ryhmiä tai tiimejä ei ole saatavilla",
    "No other groups available" : "Muita ryhmiä ei ole saatavilla",
    "{displayName} (team)" : "{displayName} (tiimi)",
    "Add group or team" : "Lisää ryhmä tai tiimi",
    "{size} used" : "{size} käytetty",
    "Other …" : "Muu…",
    "Unset" : "Poista"
},
"nplurals=2; plural=(n != 1);");
